"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ICSP = void 0;
const icsp_1 = require("./did/icsp");
const agent_1 = require("@dfinity/agent");
const nanoid_1 = require("nanoid");
const bucket_1 = require("../bucket");
const chunkSize = 1992288;
class ICSP {
    constructor(icspCanisterId, agent) {
        this.agent = agent;
        this.icspCanisterId = icspCanisterId;
        this.ICSPActor = agent_1.Actor.createActor(icsp_1.idlFactory, { agent, canisterId: this.icspCanisterId });
    }
    async getBucketActor(canisterId) {
        try {
            return agent_1.Actor.createActor(icsp_1.idlFactory, { agent: this.agent, canisterId });
        }
        catch (e) {
            throw e;
        }
    }
    async get_cycle_balance() {
        try {
            return (await this.ICSPActor.getCycleBalance());
        }
        catch (e) {
            throw e;
        }
    }
    async init() {
        try {
            return await this.ICSPActor.init();
        }
        catch (e) {
            throw e;
        }
    }
    /*
    * @argument
    *   file_key:the unique key of file
    *
    * @return
    *   the bucket store this file
    * */
    async get_bucket_of_file(file_key) {
        try {
            return (await this.ICSPActor.getBucketOfFile(file_key));
        }
        catch (e) {
            throw e;
        }
    }
    /*
    * @return: All buckets under this icsp
    * */
    async get_icsp_buckets() {
        try {
            return (await this.ICSPActor.getBuckets());
        }
        catch (e) {
            throw e;
        }
    }
    /*
    * @argument:
    *   files:files to upload
    *   is_http_open:Is it possible to access via http
    *@return :null
    * */
    async store_file(files, is_http_open) {
        const Actor = this.ICSPActor;
        try {
            const allPromise = [];
            for (let i = 0; i < files.length; i++) {
                const file = files[i];
                const key = (0, nanoid_1.nanoid)();
                const total_size = file.size;
                const total_index = Math.ceil(total_size / chunkSize);
                const file_type = file.type;
                let start = 0;
                let currentChunk = 0;
                const allData = [];
                let blobSlice = //@ts-ignore
                 File.prototype.slice ||
                    //@ts-ignore
                    File.prototype.mozSlice ||
                    //@ts-ignore
                    File.prototype.webkitSlice;
                let reader = new FileReader();
                reader.onload = async function (e) {
                    const data = new Uint8Array(e.target.result);
                    allData.push(data);
                    if (currentChunk === total_index) {
                        for (let i = 0; i < allData.length; i++) {
                            const arg = {
                                key,
                                value: allData[i],
                                file_type,
                                index: BigInt(i),
                                total_index: BigInt(total_index),
                                total_size: BigInt(total_size),
                                is_http_open
                            };
                            console.log(arg);
                            allPromise.push(Actor.store(arg));
                        }
                        if (i === files.length - 1) {
                            console.log(allPromise);
                            await Promise.all(allPromise);
                            return 0;
                        }
                    }
                    else
                        loadChunk();
                };
                const loadChunk = () => {
                    const end = start + chunkSize;
                    currentChunk++;
                    reader.readAsArrayBuffer(blobSlice.call(file, start, end));
                    start = end;
                };
                loadChunk();
            }
        }
        catch (e) {
            throw e;
        }
    }
    async get_file(fileKey) {
        try {
            const bucket = (await this.get_bucket_of_file(fileKey))[0];
            if (bucket) {
                const bucketApi = new bucket_1.Bucket(String(bucket), this.agent);
                return await bucketApi.get_file(fileKey);
            }
            else {
                throw new Error("There is no bucket to store this file");
            }
        }
        catch (e) {
            throw e;
        }
    }
}
exports.ICSP = ICSP;
