"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ISP = void 0;
const agent_1 = require("@dfinity/agent");
const isp_1 = require("./did/isp");
const xtc_1 = require("./did/xtc");
const common_1 = require("../utils/common");
const icsp_1 = require("../icsp");
class ISP {
    constructor(agent) {
        this.canisterId = "p2pki-xyaaa-aaaan-qatua-cai";
        this.agent = agent;
        this.ISPActor = agent_1.Actor.createActor(isp_1.idlFactory, { agent, canisterId: this.canisterId });
    }
    async getXTCActor() {
        return agent_1.Actor.createActor(xtc_1.idlFactory, { agent: this.agent, canisterId: "aanaa-xaaaa-aaaah-aaeiq-cai" });
    }
    async get_user_icsps() {
        try {
            return (await this.ISPActor.getUserICSPs());
        }
        catch (e) {
            throw e;
        }
    }
    async get_sub_account() {
        try {
            const userSubAccount = (await this.ISPActor.getSubAccount());
            return (0, common_1.ArrayToHexString)(userSubAccount);
        }
        catch (e) {
            throw e;
        }
    }
    async get_icp_balance() {
        try {
            return (await this.ISPActor.getICPBalance());
        }
        catch (e) {
            throw e;
        }
    }
    async transfer_out_icp(accountAdress) {
        try {
            const u8Account = (0, common_1.getUint8ArrayFromHex)(accountAdress);
            return (await this.ISPActor.transferOutICP(Array.from(u8Account)));
        }
        catch (e) {
            throw e;
        }
    }
    /*
    * @argument
    *   icspName:the name of icsp
    *
    *   icp_to_create_amount:e8s icp amount to create canister
    *
    *   xtc_to_topup_amount:e8s icp amount burn xtc to topup canister
    */
    async create_icsp(createArgs) {
        try {
            const icspCai = (await this.ISPActor.createICSP(createArgs.icspName, createArgs.icp_to_create_amount));
            if (Object.keys(icspCai)[0] === "ok") {
                const burnRes = (await this.top_up_icsp_with_xtc(icspCai.ok, createArgs.xtc_to_topup_amount));
                if (Object.keys(burnRes)[0] === "Ok") {
                    const icspApi = new icsp_1.ICSP(icspCai.ok.toString(), this.agent);
                    await icspApi.init();
                    return {
                        icspCanisterId: icspCai,
                        burnTransactionId: burnRes
                    };
                }
                else
                    throw new Error(Object.keys(burnRes.Err)[0]);
            }
            else
                throw new Error(Object.keys(icspCai.err)[0]);
        }
        catch (e) {
            throw e;
        }
    }
    async top_up_icsp_with_xtc(canisterId, amount) {
        try {
            const Actor = await this.getXTCActor();
            const burnArgs = {
                canister_id: canisterId,
                amount: amount
            };
            return await Actor.burn(burnArgs);
        }
        catch (e) {
            throw e;
        }
    }
    /*
    * @argument
    *   icsp_canisterId:the canisterPrincipal of icsp
    *
    *   icp_amount:e8s icp amount
    */
    async top_up_icsp(topUpArg) {
        try {
            return (await this.ISPActor.topUpICSP(topUpArg));
        }
        catch (e) {
            throw e;
        }
    }
}
exports.ISP = ISP;
